Usage
=====

The examples in the following pages illustrate how to use the tools that
`tensorwaves` offers. The examples were written as Jupyter notebooks and can be
downloaded `here
<https://github.com/ComPWA/tensorwaves/tree/master/docs/usage>`_.

.. toctree::
  :maxdepth: 2
  :glob:

  usage/1_create_model
  usage/2_generate_data
  usage/3_perform_fit
